package java.sql;

import java.io.ObjectOutputStream;
import java.io.IOException;
import java.io.InvalidObjectException;
import java.io.ObjectInputStream;
import java.util.Arrays;

public class BatchUpdateException extends SQLException
{
    private int[] updateCounts;
    private long[] longUpdateCounts;
    private static final long serialVersionUID = 5977529877145521757L;
    
    public BatchUpdateException(String s, String s2, int n, int[] original) {
        super(s, s2, n);
        this.updateCounts = ((original == null) ? null : Arrays.copyOf(original, original.length));
        this.longUpdateCounts = ((original == null) ? null : copyUpdateCount(original));
    }
    
    public BatchUpdateException(String s, String s2, int[] array) {
        this(s, s2, 0, array);
    }
    
    public BatchUpdateException(String s, int[] array) {
        this(s, null, 0, array);
    }
    
    public BatchUpdateException(int[] array) {
        this(null, null, 0, array);
    }
    
    public BatchUpdateException() {
        this(null, null, 0, (int[])null);
    }
    
    public BatchUpdateException(Throwable t) {
        this((t == null) ? null : t.toString(), null, 0, (int[])null, t);
    }
    
    public BatchUpdateException(int[] array, Throwable t) {
        this((t == null) ? null : t.toString(), null, 0, array, t);
    }
    
    public BatchUpdateException(String s, int[] array, Throwable t) {
        this(s, null, 0, array, t);
    }
    
    public BatchUpdateException(String s, String s2, int[] array, Throwable t) {
        this(s, s2, 0, array, t);
    }
    
    public BatchUpdateException(String s, String s2, int n, int[] original, Throwable t) {
        super(s, s2, n, t);
        this.updateCounts = ((original == null) ? null : Arrays.copyOf(original, original.length));
        this.longUpdateCounts = ((original == null) ? null : copyUpdateCount(original));
    }
    
    public int[] getUpdateCounts() {
        return (this.updateCounts == null) ? null : Arrays.copyOf(this.updateCounts, this.updateCounts.length);
    }
    
    public BatchUpdateException(String s, String s2, int n, long[] original, Throwable t) {
        super(s, s2, n, t);
        this.longUpdateCounts = ((original == null) ? null : Arrays.copyOf(original, original.length));
        this.updateCounts = ((this.longUpdateCounts == null) ? null : copyUpdateCount(this.longUpdateCounts));
    }
    
    public long[] getLargeUpdateCounts() {
        return (this.longUpdateCounts == null) ? null : Arrays.copyOf(this.longUpdateCounts, this.longUpdateCounts.length);
    }
    
    private static long[] copyUpdateCount(int[] array) {
        long[] array2 = new long[array.length];
        for (int i = 0; i < array.length; ++i) {
            array2[i] = (long)array[i];
        }
        return array2;
    }
    
    private static int[] copyUpdateCount(long[] array) {
        int[] array2 = new int[array.length];
        for (int i = 0; i < array.length; ++i) {
            array2[i] = (int)array[i];
        }
        return array2;
    }
    
    private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
        ObjectInputStream.GetField fields = objectInputStream.readFields();
        int[] array = (int[])(int[])fields.get("updateCounts", null);
        long[] array2 = (long[])(long[])fields.get("longUpdateCounts", null);
        if (array != null && array2 != null && array.length != array2.length) {
            throw new InvalidObjectException("update counts are not the expected size");
        }
        if (array != null) {
            this.updateCounts = (int[])array.clone();
        }
        if (array2 != null) {
            this.longUpdateCounts = (long[])array2.clone();
        }
        if (this.updateCounts == null && this.longUpdateCounts != null) {
            this.updateCounts = copyUpdateCount(this.longUpdateCounts);
        }
        if (this.longUpdateCounts == null && this.updateCounts != null) {
            this.longUpdateCounts = copyUpdateCount(this.updateCounts);
        }
        return;
    }
    
    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException, ClassNotFoundException {
        ObjectOutputStream.PutField putFields = objectOutputStream.putFields();
        putFields.put("updateCounts", this.updateCounts);
        putFields.put("longUpdateCounts", this.longUpdateCounts);
        objectOutputStream.writeFields();
    }
}
